Inference
=========

.. currentmodule:: graspologic.inference

Two-graph hypothesis testing
----------------------------

.. autofunction:: latent_position_test

.. autofunction:: latent_distribution_test
